Browbeat OSP Performance Tuning Playbook
========================================

This playbook aims to tune OSP deployed on Red Hat Enterprise Linux.

The playbook in here is currently experimental.
